AsXmlDyn

Trait AsXmlDyn 

pub trait AsXmlDyn {
    // Required method
    fn as_xml_dyn_iter<'x>(
        &'x self,
    ) -> Result<Box<dyn Iterator<Item = Result<Item<'x>, Error>> + 'x>, Error>;
}
Dyn-compatible version of AsXml.

This trait is automatically implemented for all types which implement AsXml.

Required Methods

fn as_xml_dyn_iter<'x>( &'x self, ) -> Result<Box<dyn Iterator<Item = Result<Item<'x>, Error>> + 'x>, Error>

Return an iterator which emits the contents of the struct or enum as serialisable Item items.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T: AsXml> AsXmlDyn for T